"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLatestDependencyVersion = void 0;
const http_1 = require("http");
function getLatestDependencyVersion(packageName) {
    const DEFAULT_VERSION = 'latest';
    return new Promise((resolve) => {
        return (0, http_1.get)(`http://registry.npmjs.org/${packageName}`, (res) => {
            let rawData = '';
            res.on('data', (chunk) => (rawData += chunk));
            res.on('end', () => {
                try {
                    const response = JSON.parse(rawData);
                    const version = (response && response['dist-tags']) || {};
                    resolve(buildPackage(packageName, version.latest));
                }
                catch (e) {
                    resolve(buildPackage(packageName));
                }
            });
        }).on('error', () => resolve(buildPackage(packageName)));
    });
    function buildPackage(name, version = DEFAULT_VERSION) {
        return { name, version };
    }
}
exports.getLatestDependencyVersion = getLatestDependencyVersion;
//# sourceMappingURL=get-latest-dependency-version.js.map